searchData={"items":[{"type":"behaviour","title":"Minch","doc":"A WebSocket client build around `Mint.WebSocket`.","ref":"Minch.html"},{"type":"behaviour","title":"Usage - Minch","doc":"#","ref":"Minch.html#module-usage"},{"type":"behaviour","title":"Supervised client - Minch","doc":"```elixir\ndefmodule EchoClient do\n  use Minch\n\n  require Logger\n\n  def start_link(init_arg) do\n    Minch.start_link(__MODULE__, init_arg, name: __MODULE__)\n  end\n\n  @impl true\n  def init(_init_arg) do\n    {:ok, %{connected?: false}}\n  end\n\n  @impl true\n  def connect(_state) do\n    url = \"wss://ws.postman-echo.com/raw\"\n    headers = [{\"authorization\", \"bearer: example\"}]\n    # don't do this in production\n    options = [transport_opts: [{:verify, :verify_none}]]\n    {url, headers, options}\n  end\n\n  @impl true\n  def handle_connect(state) do\n    Logger.info(\"connected\")\n    Process.send_after(self(), :produce, 5000)\n    {:reply, {:text, \"welcome\"}, %{state | connected?: true}}\n  end\n\n  @impl true\n  def handle_disconnect(reason, state) do\n    Logger.warning(\"disconnected: #{inspect(reason)}\")\n    {:reconnect, 1000, %{state | connected?: false}}\n  end\n\n  @impl true\n  def handle_info(:produce, state) do\n    Process.send_after(self(), :produce, 5000)\n    {:reply, {:text, DateTime.utc_now() |> DateTime.to_iso8601()}, state}\n  end\n\n  @impl true\n  def handle_frame(frame, state) do\n    Logger.info(inspect(frame))\n    {:ok, state}\n  end\nend\n```\n\n#","ref":"Minch.html#module-supervised-client"},{"type":"behaviour","title":"Simple client - Minch","doc":"```elixir\nurl = \"wss://ws.postman-echo.com/raw\"\nheaders = []\n# don't do this in production\noptions = [transport_opts: [{:verify, :verify_none}]]\n\nIO.puts(\"checking ping to #{url}...\")\n\ncase Minch.connect(url, headers, options) do\n  {:ok, pid, ref} ->\n    Minch.send_frame(pid, {:text, to_string(System.monotonic_time())})\n\n    case Minch.receive_frame(ref, 5000) do\n      {:text, start} ->\n        ping =\n          System.convert_time_unit(\n            System.monotonic_time() - String.to_integer(start),\n            :native,\n            :millisecond\n          )\n\n        IO.puts(\"#{ping}ms\")\n\n      :timeout ->\n        IO.puts(\"timeout\")\n    end\n\n    Minch.close(pid)\n\n  {:error, error} ->\n    IO.puts(\"connection error: #{inspect(error)}\")\nend\n```","ref":"Minch.html#module-simple-client"},{"type":"function","title":"Minch.close/1","doc":"Closes a connection opened by `connect/3`.","ref":"Minch.html#close/1"},{"type":"callback","title":"Minch.connect/1","doc":"Invoked to retrieve the connection details.\n\nSee `Minch.Conn.open/3`.","ref":"Minch.html#c:connect/1"},{"type":"function","title":"Minch.connect/3","doc":"Connects to a WebSocket server.\n\nOnce connected, the function will return the connection's PID and the request reference.\n\nUse the `send_frame/2` function to send WebSocket frames to the server.\n\nIncoming WebSocket frames will be sent to the caller's mailbox as a tuple `{:frame, request_ref, frame}`.\nYou can use the `receive_frame/2` function to receive these frames.\n\nUse `Process.monitor/1` to get notified when the connection is closed by the server.","ref":"Minch.html#connect/3"},{"type":"function","title":"Example - Minch.connect/3","doc":"iex> {:ok, pid, ref} = Minch.connect(\"wss://ws.postman-echo.com/raw\", [], transport_opts: [{:verify, :verify_none}])\n    {:ok, _pid, _ref}\n    iex> Minch.send_frame(pid, {:text, \"hello\"})\n    :ok\n    iex> Minch.receive_frame(ref, 5000)\n    {:text, \"hello\"}\n    iex> Minch.close(pid)\n    :ok","ref":"Minch.html#connect/3-example"},{"type":"callback","title":"Minch.handle_connect/1","doc":"Invoked to handle a successful connection.","ref":"Minch.html#c:handle_connect/1"},{"type":"callback","title":"Minch.handle_disconnect/2","doc":"Invoked to handle a disconnect from the server or a failed connection attempt.\n\nReturning `{:reconnect, backoff, state}` will schedule a reconnect after `backoff` milliseconds.\n\nReturning `{:ok, state}` will keep the client in the disconnected state. Later you can instruct\nthe client to reconnect by sending it a message and returning `{:reconnect, state}` from the\n`c:handle_info/2` callback.","ref":"Minch.html#c:handle_disconnect/2"},{"type":"callback","title":"Minch.handle_frame/2","doc":"Invoked to handle an incoming WebSocket frame.\n\nA \"close\" frame will cause the connection to be closed but you'll still receive the frame.\n\nOther than that, Minch does not intercept nor handle control frames automatically.","ref":"Minch.html#c:handle_frame/2"},{"type":"callback","title":"Minch.handle_info/2","doc":"Invoked to handle all other messages.","ref":"Minch.html#c:handle_info/2"},{"type":"callback","title":"Minch.init/1","doc":"Invoked when the client process is started.","ref":"Minch.html#c:init/1"},{"type":"function","title":"Minch.receive_frame/2","doc":"Receives an incoming WebSocket frame.\n\nSee `connect/2`.","ref":"Minch.html#receive_frame/2"},{"type":"function","title":"Minch.send_frame/2","doc":"Sends a WebSocket frame.","ref":"Minch.html#send_frame/2"},{"type":"function","title":"Minch.start_link/3","doc":"Starts a `Minch` client process linked to the current process.","ref":"Minch.html#start_link/3"},{"type":"callback","title":"Minch.terminate/2","doc":"Invoked when the client process is about to exit.","ref":"Minch.html#c:terminate/2"},{"type":"type","title":"Minch.client/0","doc":"","ref":"Minch.html#t:client/0"},{"type":"module","title":"Minch.Conn","doc":"Minch WebSocket connection.","ref":"Minch.Conn.html"},{"type":"function","title":"Minch.Conn.close/1","doc":"Gracefully closes the connection if it's still open.","ref":"Minch.Conn.html#close/1"},{"type":"function","title":"Minch.Conn.open/3","doc":"Opens a new connection.\n\nFor the available options see `Mint.HTTP.connect/4` and `Mint.WebSocket.upgrade/5` functions.","ref":"Minch.Conn.html#open/3"},{"type":"function","title":"Minch.Conn.open?/2","doc":"Wraps `Mint.HTTP.open?/2`.","ref":"Minch.Conn.html#open?/2"},{"type":"function","title":"Minch.Conn.send_frame/2","doc":"Send a frame via the connection.","ref":"Minch.Conn.html#send_frame/2"},{"type":"function","title":"Minch.Conn.stream/2","doc":"Wraps `Mint.WebSocket.stream/2` and decodes WebSocket frames.","ref":"Minch.Conn.html#stream/2"},{"type":"type","title":"Minch.Conn.response/0","doc":"","ref":"Minch.Conn.html#t:response/0"},{"type":"type","title":"Minch.Conn.t/0","doc":"","ref":"Minch.Conn.html#t:t/0"},{"type":"module","title":"Minch.Conn.NotUpgradedError","doc":"","ref":"Minch.Conn.NotUpgradedError.html"},{"type":"type","title":"Minch.Conn.NotUpgradedError.t/0","doc":"","ref":"Minch.Conn.NotUpgradedError.html#t:t/0"},{"type":"module","title":"Minch.Conn.UpgradeFailureError","doc":"","ref":"Minch.Conn.UpgradeFailureError.html"},{"type":"type","title":"Minch.Conn.UpgradeFailureError.t/0","doc":"","ref":"Minch.Conn.UpgradeFailureError.html#t:t/0"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.1.0 (2023-10-12) - Changelog","doc":"#","ref":"changelog.html#0-1-0-2023-10-12"},{"type":"extras","title":"Features - Changelog","doc":"* initial release ([1bb8bcf](https://github.com/nmbrone/minch/commit/1bb8bcf411aa26145f8ab125986d20ef5f14f994))\n\n\n#","ref":"changelog.html#features"},{"type":"extras","title":"Miscellaneous Chores - Changelog","doc":"* trigger the release ([be8ba9e](https://github.com/nmbrone/minch/commit/be8ba9eea7a774d4d606740a3104001d8d42bc05))","ref":"changelog.html#miscellaneous-chores"}],"content_type":"text/markdown"}